@@ -18,21 +18,21 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
+import json
 import logging
 import threading
 import time
-import json
+import uuid
+
 import dbus
 import dbus.exceptions
 import dbus.mainloop.glib
 import dbus.service
-
 import shortuuid
-import uuid
 import zmq
 from gi.repository import GLib
 
-from dashio.dashdevice import DashDevice
+from dashio.dashdevice import Device
 
 from .constants import CONNECTION_PUB_URL, DEVICE_PUB_URL
 
@@ -115,6 +115,7 @@ class DashIOAdvertisement(dbus.service.Object):
     PATH_BASE = "/org/bluez/example/advertisement"
 
     def __init__(self, index, service_uuid):
+        
         self.path = self.PATH_BASE + str(index)
         self.bus = BleTools.get_bus()
         self.service_uuids = []
@@ -167,7 +168,7 @@ class NotPermittedException(dbus.exceptions.DBusException):
 
 class BLEConnection(dbus.service.Object, threading.Thread):
 
-    def add_device(self, device: DashDevice):
+    def add_device(self, device: Device):
         device.add_connection(self)
         device.add_control(self.ble_control)
         self.rx_zmq_sub.connect(DEVICE_PUB_URL.format(id=device.zmq_pub_id))
@@ -203,6 +204,13 @@ class BLEConnection(dbus.service.Object, threading.Thread):
         self.tx_zmq_pub.send_multipart([self.b_connection_id, b'1', msg.encode('utf-8')])
 
     def __init__(self, ble_uuid=None, context=None):
+        """
+        Arguments:
+        [Optional]
+            ble_uuid {str} -- The UUID used by BLE.
+            context {int} -- ZMQ context
+        """
+
         threading.Thread.__init__(self, daemon=True)
 
         self.connection_id = shortuuid.uuid()
@@ -226,6 +234,7 @@ class BLEConnection(dbus.service.Object, threading.Thread):
         dashio_service_uuid = ble_uuid or str(uuid.uuid4())
 
         self.ble_control = BLE(self.connection_id, dashio_service_uuid, dashio_service_uuid, dashio_service_uuid)
+
         GLib.threads_init()
         dbus.mainloop.glib.threads_init()
         dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
@@ -234,6 +243,7 @@ class BLEConnection(dbus.service.Object, threading.Thread):
         self.bus = BleTools.get_bus()
         self.path = "/"
         self.dash_service = DashIOService(0, dashio_service_uuid, self.ble_rx)
+        
         self.response = {}
 
         chrc = self.dash_service.get_characteristics()
