@@ -36,7 +36,7 @@ class SliderSingleBar(Control):
         self.bar_color = bar_color
         self.bar_style = bar_style
         self.knob_color = knob_color
-        self._slider_state_str = self._state_str + f"{self._slider_value}\n"
+        self._slider_state_str = self._control_hdr_str + f"{self._slider_value}\n"
         self._bar1_state_str = self._control_id_bar + f"{self._bar1_value}\n"
         self._bar_slider_state_str = self._slider_state_str + self._bar1_state_str
 
@@ -61,7 +61,7 @@ class SliderSingleBar(Control):
     @slider_value.setter
     def slider_value(self, val: float):
         self._slider_value = val
-        self._slider_state_str = self._state_str + f"{self._slider_value}\n"
+        self._slider_state_str = self._control_hdr_str + f"{self._slider_value}\n"
         self.message_tx_event(self._slider_state_str)
         self._bar_slider_state_str = self._slider_state_str + self._bar1_state_str
 
