@@ -113,7 +113,7 @@ class TimeGraph(Control):
     def send_graph(self):
         state_str = ""
         for key in self.line_dict:
-            state_str += self._state_str + key + self.line_dict[key].get_line_data()
+            state_str += self._control_hdr_str + key + self.line_dict[key].get_line_data()
         self.state_str = state_str
 
     def __get_lines_from_timestamp(self, msg):
@@ -122,7 +122,7 @@ class TimeGraph(Control):
             if self.line_dict[key].data:
                 line_data = self.line_dict[key].get_line_from_timestamp(msg[3])
                 if line_data:
-                    state_str += self._state_str + key + line_data
+                    state_str += self._control_hdr_str + key + line_data
         self.state_str = state_str
 
     def send_data(self):
@@ -131,7 +131,7 @@ class TimeGraph(Control):
             if self.line_dict[key].data:
                 line_data = self.line_dict[key].get_latest_data()
                 if line_data:
-                    state_str += self._state_str + key + line_data
+                    state_str += self._control_hdr_str + key + line_data
         self.state_str = state_str
 
     @property
